<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui version="5" name="digikamimageplugin_adjustlevels" >

 <MenuBar>

   <Menu name="Color" ><text>&amp;Color</text>
     <Action name="imageplugin_adjustlevels" /> 
   </Menu>

 </MenuBar>
 
 <ToolBar name="ToolBar" >
  <text>Main Toolbar</text>
 </ToolBar>
 
 <ActionProperties>
  <Action name="imageplugin_adjustlevels" />
 </ActionProperties>

</kpartgui>
