<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui version="5" name="digikamimageplugin_oilpaint" >

 <MenuBar>

  <Menu name="Filters" ><text>F&amp;ilters</text>
   <Action name="imageplugin_oilpaint" /> 
  </Menu>

 </MenuBar>
 
 <ToolBar name="ToolBar" >
  <text>Main Toolbar</text>
 </ToolBar>
 
 <ActionProperties>
  <Action shortcut="" name="imageplugin_oilpaint" />
 </ActionProperties>

</kpartgui>
