<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui version="4" name="digikamimageplugin_hotpixels" >

 <MenuBar>

  <Menu name="Enhance" ><text>Enh&amp;ance</text>
   <Action name="imageplugin_hotpixels" /> 
  </Menu>

 </MenuBar>
 
 <ToolBar name="ToolBar" >
  <text>Main Toolbar</text>
 </ToolBar>

 <ActionProperties>
  <Action shortcut="" name="imageplugin_hotpixels" />
 </ActionProperties>
 
</kpartgui>
