<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<gui version="23" name="lighttablewindow" >

<MenuBar>

    <Menu name="File" ><text>&amp;File</text>
        <Action name="lighttable_first" />
        <Action name="lighttable_backward" />
        <Action name="lighttable_forward" />
        <Action name="lighttable_last" />
        <Separator/>
        <Action name="lighttable_setitemleft" />
        <Action name="lighttable_setitemright" />
        <Action name="lighttable_edititem" />
        <Separator/>
        <Action name="lighttable_removeitem" />
        <Action name="lighttable_clearlist" />
        <Separator/>
        <Action name="lighttable_filedelete" />
        <Separator/>
        <Action name="lighttable_close" />
    </Menu>
    
    <Menu name="View" ><text>&amp;View</text>
        <Action name="lighttable_fullscreen" />
        <Action name="lighttable_slideshow" />
        <Separator/>
        <Action name="lighttable_syncpreview" />
        <Action name="lighttable_navigatebypair" />
        <Separator/>
        <Action name="lighttable_zoomplus" /> 
        <Action name="lighttable_zoomminus" /> 
        <Action name="lighttable_zoomto100percents" />
        <Action name="lighttable_zoomfit2window" />
    </Menu>

    <Menu name="help" ><text>&amp;Help</text>
        <Action name="lighttable_rawcameralist"/>        
        <Action name="lighttable_donatemoney" />
        <Action name="lighttable_contribute" />
    </Menu>
  
    <Merge/>

    <Menu name="settings" noMerge="1"><Text>&amp;Settings</Text>
        <Action name="options_show_toolbar"/>
        <Merge name="StandardToolBarMenuHandler" />
        <Action name="options_show_statusbar"/>
        <Separator/>
        <Action name="theme_menu" />
        <Action name="options_configure_keybinding"/>
        <Action name="options_configure_toolbars"/>
        <Action name="options_configure" />        
    </Menu>

</MenuBar>

<ToolBar name="ToolBar" ><text>Main Toolbar</text>
     <Action name="lighttable_first" />
     <Action name="lighttable_backward" />
     <Action name="lighttable_forward" />
     <Action name="lighttable_last" />
     <Separator/>     
     <Action name="lighttable_zoomplus" /> 
     <Action name="lighttable_zoomminus" /> 
     <Action name="lighttable_zoomfit2window" /> 
     <Separator/>     
     <Action name="lighttable_setitemleft" />
     <Action name="lighttable_setitemright" />
     <Action name="lighttable_syncpreview" /> 
     <Action name="lighttable_navigatebypair" />     
     <Separator/>     
     <Action name="lighttable_fullscreen" />
     <Action name="lighttable_slideshow" />      
     <Merge />
     <WeakSeparator/>
     <Action name="logo_action" />	       
</ToolBar>
 
<ActionProperties/>

</gui>
