<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui version="37" name="digikam" >

 <MenuBar>

  <Menu name="Album" >
   <text>&amp;Album</text>
     <Action name="album_back" />  
     <Action name="album_forward" />    
   <Separator/>     
     <Action name="album_new" />
   <Separator/>
     <Action name="album_propsEdit" />
     <Action name="album_refresh" />
     <Action name="album_syncmetadata" />
     <Action name="album_openinkonqui" />
   <Separator/>
     <Action name="album_remove" />
     <Action name="album_delete" />
   <Separator/>
     <Action name="app_exit" />
  </Menu>

  <Menu name="Tag" >
   <text>T&amp;ag</text>
     <Action name="tag_new" />
     <Action name="tag_edit" />
   <Separator/>
     <Action name="tag_delete" />
  </Menu>

  <Menu name="Image" >
   <text>&amp;Image</text>
     <Action name="image_view" />
     <Action name="image_edit" />
     <Action name="image_lighttable" />
     <Action name="image_add_to_lighttable" />
     <Action name="image_set_exif_orientation"/>
   <Separator />
     <ActionList name="image_actions"/>
   <Separator />
     <Action name="image_rename" />
     <Action name="image_delete" />
  </Menu>

  <Menu name="Edit" >
   <text>&amp;Edit</text>
     <Action name="selectAll" />
     <Action name="selectNone" />
     <Action name="selectInvert" />
  </Menu>

  <Menu name="View" >
   <text>&amp;View</text>
     <Action name="full_screen" />
     <Action name="slideshow" />
     <Separator/>
     <Action name="album_zoomin" />
     <Action name="album_zoomout" />
     <Action name="album_zoomto100percents" />
     <Action name="album_zoomfit2window" />
     <Separator />
     <Action name="album_sort" />
     <Action name="image_sort" />
     <Action name="albums_recursive" />
     <Action name="tags_recursive" />
  </Menu>

  <Menu name="Tools"><text>&amp;Tools</text>
        <Action name="search_quick" />
        <Action name="search_advanced" />
      <Separator/>
        <Action name="light_table" />
      <Separator/>
        <Action name="database_rescan" />
        <Action name="thumbs_rebuild" />
        <Action name="sync_metadata" />
      <Separator/>
        <ActionList name="album_actions"/>
      <Separator/>
        <ActionList name="tool_actions"/>
  </Menu>

  <Menu name="Batch"><text>&amp;Batch</text>
     <ActionList name="batch_actions"/>
  </Menu>

  <Menu name="Import"><text>&amp;Import</text>
      <Action name="camera_menu" />
      <Separator/>
      <Action name="album_addImages" />
      <Action name="album_importFolder" />
      <Separator/>
      <ActionList name="file_actions_import"/>
  </Menu>

  <Menu name="Export"><text>&amp;Export</text>
      <ActionList name="file_actions_export"/>
  </Menu>

  <Menu name="settings" noMerge="1"><Text>&amp;Settings</Text>
     <Action name="options_show_toolbar"/>
     <Merge name="StandardToolBarMenuHandler" />
     <Action name="options_show_statusbar"/>
     <Separator/>
     <Action name="theme_menu" />
     <Action name="options_configure_keybinding"/>
     <Action name="options_configure_toolbars"/>
     <Action name="options_configure"/>
  </Menu>

  <Menu name="help"><Text>&amp;Help</Text>
    <Action name="help_rawcameralist"/>
    <Action name="help_kipi"/>
    <Action name="help_tipofday"/>
    <Separator/>
    <Action name="help_donatemoney"/>
    <Action name="help_contribute" />
  </Menu>

  <Merge/>

 </MenuBar>

 <ToolBar noMerge="1" name="ToolBar" >
  <text>Main Toolbar</text>
  <Action name="album_back" />  
  <Action name="album_forward" />    
  <Action name="album_new" />
  <Action name="album_addImages" />
  <Action name="album_propsEdit" />
  <Separator/>
  <Action name="search_quick" />
  <Separator/>
  <Action name="image_view" />
  <Action name="image_edit" />
  <Action name="image_rename" />
  <Separator/>
  <Action name="full_screen" />
  <Action name="slideshow" />
  <WeakSeparator/>
  <Action name="logo_action" />
 </ToolBar>
 <ActionProperties/>

</kpartgui>
